@@ -34,23 +34,23 @@ test_that("checkbox choices -digits", {
     )
 
   # well-behaved
-  "1, American Indian/Alaska Native | -2, Asian | 3, Native Hawaiian or Other Pacific Islander | 4, Black or African American | 5, White | 66, Unknown / Not Reported" |>
-    checkbox_choices() |>
+  "1, American Indian/Alaska Native | -2, Asian | 3, Native Hawaiian or Other Pacific Islander | 4, Black or African American | 5, White | 66, Unknown / Not Reported" %>%
+    checkbox_choices() %>%
     expect_equal(ds_expected, label = "well-behaved:")
 
   # no leading spaces
-  "1, American Indian/Alaska Native |-2, Asian |3, Native Hawaiian or Other Pacific Islander |4, Black or African American |5, White |66, Unknown / Not Reported" |>
-    checkbox_choices() |>
+  "1, American Indian/Alaska Native |-2, Asian |3, Native Hawaiian or Other Pacific Islander |4, Black or African American |5, White |66, Unknown / Not Reported" %>%
+    checkbox_choices() %>%
     expect_equal(ds_expected, label = "no leading spaces:")
 
   # no trailing spaces
-  "1, American Indian/Alaska Native| -2, Asian| 3, Native Hawaiian or Other Pacific Islander| 4, Black or African American| 5, White| 66, Unknown / Not Reported" |>
-    checkbox_choices() |>
+  "1, American Indian/Alaska Native| -2, Asian| 3, Native Hawaiian or Other Pacific Islander| 4, Black or African American| 5, White| 66, Unknown / Not Reported" %>%
+    checkbox_choices() %>%
     expect_equal(ds_expected, label = "no trailing spaces:")
 
   # extra lines
-  "| | 1, American Indian/Alaska Native | | | -2, Asian | 3, Native Hawaiian or Other Pacific Islander | 4, Black or African American | 5, White | 66, Unknown / Not Reported | | | " |>
-    checkbox_choices() |>
+  "| | 1, American Indian/Alaska Native | | | -2, Asian | 3, Native Hawaiian or Other Pacific Islander | 4, Black or African American | 5, White | 66, Unknown / Not Reported | | | " %>%
+    checkbox_choices() %>%
     expect_equal(ds_expected, label = "extra lines:")
 })
 
@@ -67,18 +67,18 @@ test_that("checkbox choices -letters", {
     )
 
   # well-behaved
-  "a, American Indian/Alaska Native | b, Asian | c, Native Hawaiian or Other Pacific Islander | dd, Black or African American | eee, White | f, Unknown / Not Reported" |>
-    checkbox_choices() |>
+  "a, American Indian/Alaska Native | b, Asian | c, Native Hawaiian or Other Pacific Islander | dd, Black or African American | eee, White | f, Unknown / Not Reported" %>%
+    checkbox_choices() %>%
     expect_equal(ds_expected, label = "well-behaved:")
 
   # no leading spaces
-  "a, American Indian/Alaska Native |b, Asian |c, Native Hawaiian or Other Pacific Islander |dd, Black or African American |eee, White |f, Unknown / Not Reported" |>
-    checkbox_choices() |>
+  "a, American Indian/Alaska Native |b, Asian |c, Native Hawaiian or Other Pacific Islander |dd, Black or African American |eee, White |f, Unknown / Not Reported" %>%
+    checkbox_choices() %>%
     expect_equal(ds_expected, label = "no leading spaces:")
 
   # no trailing spaces
-  "a, American Indian/Alaska Native| b, Asian| c, Native Hawaiian or Other Pacific Islander| dd, Black or African American| eee, White| f, Unknown / Not Reported" |>
-    checkbox_choices() |>
+  "a, American Indian/Alaska Native| b, Asian| c, Native Hawaiian or Other Pacific Islander| dd, Black or African American| eee, White| f, Unknown / Not Reported" %>%
+    checkbox_choices() %>%
     expect_equal(ds_expected, label = "no trailing spaces:")
 })
 
@@ -95,18 +95,18 @@ test_that("checkbox choices -commas in labels", {
     )
 
   # well-behaved
-  "a, American Indian, Native American, or Alaska Native | b, Asian | c, Native Hawaiian, Samoan, or Other Pacific Islander | dd, Black or African American | eee, White | f, Unknown / Not Reported" |>
-    checkbox_choices() |>
+  "a, American Indian, Native American, or Alaska Native | b, Asian | c, Native Hawaiian, Samoan, or Other Pacific Islander | dd, Black or African American | eee, White | f, Unknown / Not Reported" %>%
+    checkbox_choices() %>%
     expect_equal(ds_expected, label = "well-behaved:")
 
   # no leading spaces
-  "a, American Indian, Native American, or Alaska Native |b, Asian |c, Native Hawaiian, Samoan, or Other Pacific Islander |dd, Black or African American |eee, White |f, Unknown / Not Reported" |>
-    checkbox_choices() |>
+  "a, American Indian, Native American, or Alaska Native |b, Asian |c, Native Hawaiian, Samoan, or Other Pacific Islander |dd, Black or African American |eee, White |f, Unknown / Not Reported" %>%
+    checkbox_choices() %>%
     expect_equal(ds_expected, label = "no leading spaces:")
 
   # no trailing spaces
-  "a, American Indian, Native American, or Alaska Native| b, Asian| c, Native Hawaiian, Samoan, or Other Pacific Islander| dd, Black or African American| eee, White| f, Unknown / Not Reported" |>
-    checkbox_choices() |>
+  "a, American Indian, Native American, or Alaska Native| b, Asian| c, Native Hawaiian, Samoan, or Other Pacific Islander| dd, Black or African American| eee, White| f, Unknown / Not Reported" %>%
+    checkbox_choices() %>%
     expect_equal(ds_expected, label = "no trailing spaces:")
 })
 
@@ -121,23 +121,23 @@ test_that("checkbox choices -digits only", {
     )
 
   # well-behaved
-  "1, 1 | 2, 2 | 3, 3 | 4, 4" |>
-    checkbox_choices() |>
+  "1, 1 | 2, 2 | 3, 3 | 4, 4" %>%
+    checkbox_choices() %>%
     expect_equal(ds_expected, label = "well-behaved:")
 
   # missing leading space
-  "1, 1 | 2,2 | 3, 3 | 4, 4" |>
-    checkbox_choices() |>
+  "1, 1 | 2,2 | 3, 3 | 4, 4" %>%
+    checkbox_choices() %>%
     expect_equal(ds_expected, label = "missing leading space:")
 
   # missing trailing spaces
-  "1, 1 | 2, 2| 3, 3| 4, 4" |>
-    checkbox_choices() |>
+  "1, 1 | 2, 2| 3, 3| 4, 4" %>%
+    checkbox_choices() %>%
     expect_equal(ds_expected, label = "no leading spaces:")
 
   # extra lines
-  "|1, 1 | 2, 2 | 3, 3 || 4, 4| |" |>
-    checkbox_choices() |>
+  "|1, 1 | 2, 2 | 3, 3 || 4, 4| |" %>%
+    checkbox_choices() %>%
     expect_equal(ds_expected, label = "well-behaved:")
 })
 
@@ -151,8 +151,8 @@ test_that("checkbox choices with special characters", {
       "4", "Hospítal D"
     )
 
-  "1, Hospital A | 2, Hospitäl B | 3, Hospital Ç | 4, Hospítal D" |>
-    checkbox_choices() |>
+  "1, Hospital A | 2, Hospitäl B | 3, Hospital Ç | 4, Hospítal D" %>%
+    checkbox_choices() %>%
     expect_equal(ds_expected)
 })
 
@@ -184,7 +184,7 @@ test_that("checkbox choices with errant space", {
       "0",                "Not Noted"
     )
 
-  "1, Depressive mood disorder | 2, Adjustment disorder| 3, Personality disorder | 4, Anxiety | 0, Not Noted" |>
-    checkbox_choices() |> # datapasta::tribble_paste()
+  "1, Depressive mood disorder | 2, Adjustment disorder| 3, Personality disorder | 4, Anxiety | 0, Not Noted" %>%
+    checkbox_choices() %>% # datapasta::tribble_paste()
     expect_equal(ds_expected)
 })
